<?php

namespace Drupal\monarch_bootstrap\Plugin\Preprocess;

/**
 * Pre-processes variables for buttons.
 *
 * @MonarchPreprocess("input")
 */
class Input extends PreprocessBase {

  /**
   * {@inheritdoc}
   */
  public function preprocess(array &$variables, $hook, array $info) {
    parent::preprocess($variables, $hook, $info);
    $settings = $this->getThemeSetting('components.input');

    // Make Fallbacks to allow the site to function with invalid config.
    $settings = (empty($settings) ? [] : $settings);
    $settings['submit_class'] = ($settings['submit_class'] ?? '');
    $settings['button_class'] = ($settings['button_class'] ?? '');
    $variables['element']['#button_type'] = ($variables['element']['#button_type'] ?? '');
    $variables['element']['#type'] = ($variables['element']['#type'] ?? '');
    $variables['attributes']['class'] = ($variables['attributes']['class'] ?? []);

    // Let the developers know if there is invalid config.
    if (defined('ERROR_REPORTING_DISPLAY_VERBOSE')) {
      if (ERROR_REPORTING_DISPLAY_VERBOSE === 'verbose') {
        $message = ['Invalid Theme Config' . $hook];
        if (empty($settings)) {
          $message[] = 'Empty $settings';
        }
        else {
          if (empty($settings['submit_class'])) {
            $message[] = 'Empty $settings["submit_class"]';
          }
          if (empty($settings['button_class'])) {
            $message[] = 'Empty $settings["button_class"]';
          }
        }
        if (empty($variables)) {
          $message[] = 'Empty $variables';
        }
        else {
          if (empty($variables['element']['#button_type'])) {
            $message[] = 'Empty $variables["element"]["#button_type"]';
          }
          if (empty($variables['element']['#type'])) {
            $message[] = 'Empty $variables["element"]["#type"]';
          }
        }
        if (count($message) > 1) {
          \Drupal::logger('monarch_bootstrap')->error(implode(' & ', $message));
        }
      }
    }

    if ($variables['element']['#button_type'] == 'primary') {
      if ($settings['submit_class'] != 'none') {
        $variables['attributes']['class'][] = $settings['submit_class'];
      }
    }
    elseif ($variables['element']['#type'] == 'submit') {
      $variables['attributes']['class'][] = $settings['button_class'];
    }
  }

}
